@@ -33,7 +33,7 @@ def config(cnvrg, logger, check, organization):
         return
     config_file = Config()
     try:
-        if check:
+        if check is not None:
             config_file.check_certificate = bool(check)
         if organization:
             cnvrg._context.ensure_organization_exist(name=organization)
