@@ -23,16 +23,21 @@ DATA_DOWNLOAD_SUCCESS = "Successfully downloaded updated files"
 DATA_COMMIT_MESSAGE = "Commit message"
 DATA_UPLOAD_HELP_GIT_DIFF = "From the list of files, upload those who returned from git diff command."
 DATA_PROMPT_COMMIT = "Please enter sha1 to clone"
+DATA_PROMPT_CACHE = "Please enter sha1 to cache"
+DATA_DOWNLOAD_ERROR = "Unexpected error while executing command"
 
 
 # DATASET
 DATASET_PROMPT_CLONE = "Please enter dataset name to clone"
 DATASET_HELP_CLONE = "Name of the dataset to clone"
+DATASET_HELP_CACHE = "Name of the dataset to cache"
+DATASET_HELP_UNCACHE = "Name of the dataset to uncache"
 DATASET_HELP_CLONE_OVERRIDE = "Whether or not re-clone in case the dataset already cloned"
 DATASET_HELP_CLONE_COMMIT = "The commit sha1 to clone"
 DATASET_CLONE_SKIP = "Dataset {0} is already cloned, therefore skip clone." \
                      " If you want to override, run again using -o flag."
 DATASET_PROMPT_NAME = "Please enter dataset name"
+DATASET_PROMPT_DISK_NAME = "Please enter disk name"
 DATASET_HELP_NAME = "Name of the dataset"
 DATASET_CLONE_SUCCESS = "Successfully cloned dataset: {0}"
 DATASET_PUT_PROMPT_FILES = "Please enter a comma separated list of file paths to upload. use . " \
@@ -42,21 +47,49 @@ DATASET_PUT_HELP_FILES = "A comma separated list of file paths to upload. use .
 DATASET_REMOVE_PROMPT_FILES = "Please enter a comma separated list of file paths to remove. Wildcards allowed"
 DATASET_REMOVE_HELP_FILES = "A comma separated list of file paths to remove. use Wildcards allowed"
 DATASET_REMOVE_SUCCESS = "Files removed successfully"
+DATASET_PROMPT_DELETE = "Please enter dataset name to delete"
+DATASET_HELP_DELETE = "Name of the dataset to delete"
+DATASET_DELETE_CONFIRM = "Are you sure you want to delete dataset: {0}?"
+DATASET_DELETE_SUCCESS = "Successfully deleted dataset: {0}"
+DATASET_SYNC_SUCCESS = "Successfully synced dataset {0}"
+DATASET_PROMPT_CREATE = "Please enter dateset name to create"
+DATASET_HELP_CREATE = "Name for the new dataset"
+DATASET_CREATE_FOLDER_NOT_EMPTY = "Warning! You're about to associate a non empty folder with the new dataset." \
+                                  "\r\nContinue?"
+DATASET_CREATING_MESSAGE = "Creating new dataset {0}"
+DATASET_CONFIGURING_FOLDER = "Configuring dataset folder"
+DATASET_CREATE_SUCCESS = "Successfully created dataset {0}"
+DATASET_SCAN_START = "Scanning datasets"
+DATASET_SCAN_NO_RESULTS = "No datasets found in working dir"
+DATASET_VERIFY_STATUS = "Success: {0}"
+DATASET_UNCACHE_SUCCESS = "Dataset successfully uncached"
+DATASET_CACHE_SUCCESS = "Dataset successfully cached"
+DATASET_NAMES = "Dataset names"
+DATASET_NAMES_HELP = "Dataset names to verify"
+DATASET_VERIFY_TIMEOUT = "Timeout"
 
 # PROJECT
 PROJECT_PROMPT_CLONE = "Please enter project name to clone"
 PROJECT_HELP_CLONE = "Name of the project to clone"
+PROJECT_PROMPT_DELETE = "Please enter project name to delete"
+PROJECT_HELP_DELETE = "Name of the project to delete"
 PROJECT_HELP_CLONE_OVERRIDE = "Whether or not re-clone in case the project already cloned"
 PROJECT_HELP_CLONE_COMMIT = "The commit sha1 to clone"
 PROJECT_CLONE_SKIP = "Project {0} is already cloned, therefore skip clone." \
                      " If you want to override, run again using -o flag."
 PROJECT_CLONE_SUCCESS = "Successfully cloned project: {0}"
-PROJECT_UPLOAD_SUCCESS = "Successfully uploaded updated files"
+PROJECT_DELETE_SUCCESS = "Successfully deleted project: {0}"
+PROJECT_DELETE_CONFIRM = "Are you sure you want to delete project: {0}?"
 PROJECT_DOWNLOAD_SUCCESS = "Successfully downloaded updated files"
 PROJECT_LINK_PROMPT_NAME = "Please enter a name for the new project"
 PROJECT_LINK_HELP_NAME = "Name for the new project"
+PROJECT_PROMPT_NAME = "Please enter project name"
+PROJECT_HELP_NAME = "Name of the project"
 PROJECT_LINK_GIT_PROMPT_NAME = "Please enter the name of the git project"
 PROJECT_LINK_GIT_HELP_NAME = "Name of the git project"
+SOFT_LINK_GIT_PROJECT = "Link the git project, if it hasn't done before"
+PROJECT_GIT_LINK_SKIP = "Project {0} is already linked, therefore skip linking"
+PROJECT_JOB_SLUG_HELP_NAME = "Slug of the job"
 PROJECT_LINK_SUCCESS = "Finished linking project {0} successfully."
 PROJECT_CREATE_NEW = "Creating new project {0}"
 PROJECT_CONFIGURING_FOLDER = "Configuring project folder"
@@ -67,8 +100,13 @@ PROJECT_CREATE_FOLDER_NOT_EMPTY = "Warning! You're about to associate a non empt
                                   "\r\nContinue?"
 PROJECT_CREATING_PROJECT = "Creating new project {0}"
 PROJECT_CREATE_SUCCESS = "Successfully created project {0}"
+PROJECT_SYNC_SUCCESS = "Successfully synced project {0}"
 PROJECT_DOWNLOAD_HELP_COMMIT = "Sha1 of the commit to download"
 
+# FILES
+FILES_UPLOAD_SUCCESS = "Successfully uploaded files"
+COMMIT_SHA1_MESSAGE = "Commit sha1: {0}"
+
 # LIBRARIES
 LIBRARY_PROMPT_CLONE = "Please enter library name to clone"
 LIBRARY_VERSION_PROMPT_CLONE = "Please enter library version name to clone (default = \"latest\")"
@@ -78,6 +116,8 @@ LIBRARY_CLONE_SUCCESS = "Successfully cloned project: {0}"
 
 # EXPERIMENT
 EXPERIMENT_PROMPT_TITLE = "Please enter a title for the experiment"
+EXPERIMENT_PROMPT_COMMIT = "Please enter commit to merge"
+EXPERIMENT_HELP_COMMIT = "Commit sha1 to merge"
 EXPERIMENT_HELP_TITLE = "Name of the experiment"
 EXPERIMENT_HELP_TEMPLATES = "Comma separated list of template names"
 EXPERIMENT_HELP_LOCAL = "Boolean. Run the experiment locally"
@@ -91,6 +131,9 @@ EXPERIMENT_HELP_IMAGE = "Image name and tag to create experiment with. format -
 EXPERIMENT_HELP_GIT_BRANCH = "The branch to pull files from for the experiment, in case project is git project"
 EXPERIMENT_HELP_GIT_COMMIT = "The commit to pull files from for the experiment, in case project is git project"
 EXPERIMENT_CREATE_SUCCESS = "Experiment {0} created successfully. \r\nExperiment is available at: {1}"
+EXPERIMENT_MERGE_SUCCESS = "Commit successfully merged to master"
+EXPERIMENT_GIT_ERROR_MESSAGE = "Cannot merge commits for git projects"
+EXPERIMENT_DOES_NOT_EXIST = "Couldn't find experiment. Try with env variables or passing --slug"
 
 # LOGS
 LOG_START_COMMAND = "Starting command {0}. Options: {1}"
