@@ -6,6 +6,7 @@ from cnvrgv2.context import Context, SCOPE
 from cnvrgv2.modules.images.images_client import ImagesClient
 from cnvrgv2.modules.ssh.ssh_client import SshClient
 from cnvrgv2.modules.users.users_client import UsersClient
+from cnvrgv2.modules.members.members_client import MembersClient
 from cnvrgv2.modules.users.user import User, ROLES
 from cnvrgv2.modules.projects_client import ProjectsClient
 from cnvrgv2.modules.libhub.libraries.libraries_client import LibrariesClient
@@ -133,6 +134,7 @@ class Cnvrg:
             self.settings = OrganizationSettings(self)
             self.clusters = ClustersClient(self)
             self.ssh = SshClient(self)
+            self.members = MembersClient(self)
 
         except CnvrgError:
             # TODO: How to handle exceptions
