@@ -40,6 +40,7 @@ NOT_A_VOLUME_OBJECT = "The given argument is not a Volume object. please provide
 
 # COMMIT
 COMMIT_FAULTY_SHA1 = "Commit sha1 must be a string"
+LOCAL_COMMIT_DOESNT_EXIST_ERROR = "Local commit does not exist. Can't save config"
 
 # PROJECT
 PROJECT_GET_FAULTY_SLUG = "Cannot get project with empty slug or a non string slug"
@@ -140,6 +141,7 @@ CREDENTIALS_MISSING = "Some credentials are missing. Cannot authenticate, try lo
 # CLI - PROJECT
 DIRECTORY_ALREADY_LINKED = "Directory is already linked to {0}"
 NOT_A_GIT_PROJECT = "Project {0} is not a git project"
+PROJECT_NOT_EXIST = "Project {0} is not a cnvrg project"
 
 # CLI - SSH
 SSH_FAILED_TO_START = "Failed to start ssh. Ssh status: {0}"
