@@ -5,6 +5,7 @@ VERSION = "v2/version/"
 ORGANIZATION_BASE = "v2/{0}/"
 ORGANIZATION_SETTINGS = "v2/{0}/settings"
 ORGANIZATION_USERS = "v2/{0}/users"
+ORGANIZATION_MEMBERS = "v2/{0}/members"
 ORGANIZATION_CREATE = "v2/organizations"
 
 # USER
@@ -34,8 +35,10 @@ LIBRARY_VERSIONS_BASE = "v2/{0}/libhub/libraries/{1}/versions/"
 LIBRARY_VERSION_BASE = "v2/{0}/libhub/libraries/{1}/versions/{2}"
 
 # COMMIT
-COMMITS_BASE = "v2/{0}/datasets/{1}/commits/"
-COMMIT_BASE = "v2/{0}/datasets/{1}/commits/{2}"
+DATASET_COMMITS_BASE = "v2/{0}/datasets/{1}/commits/"
+DATASET_COMMIT_BASE = "v2/{0}/datasets/{1}/commits/{2}"
+PROJECT_COMMITS_BASE = "v2/{0}/projects/{1}/commits/"
+PROJECT_COMMIT_BASE = "v2/{0}/projects/{1}/commits/"
 COMMIT_REMOVE_FILES = "commits/{0}/remove_files?page[size]=1000&sort=id"
 
 # QUERIES
