@@ -43,6 +43,9 @@ class S3Storage(BaseStorageClient):
     def download_single_file(self, local_path, object_path, progress_bar=None):
         try:
             create_dir_if_not_exists(local_path)
+            if not object_path:
+                return
+
             self.client.download_file(
                 self.bucket,
                 object_path,
