@@ -147,7 +147,8 @@ class LocalFilesHandler:
                 if self.progress_bar_enabled:
                     chunk_progress = 0
                     for file_name in chunk:
-                        if not any(file for file in files_to_upload if file["fullpath"] == file_name):
+                        if not any(file for file in files_to_upload
+                                   if file["fullpath"] == self._normalize_file_name(file_name)):
                             file_size = files_metadata[file_name]["file_size"] if files_metadata[file_name] else 0
                             chunk_progress += file_size
                     converted_bytes, unit = convert_bytes(chunk_progress, self.progress_bar.unit)
@@ -162,6 +163,11 @@ class LocalFilesHandler:
                     except Full:
                         time.sleep(0.5)
 
+    def _normalize_file_name(self, file_name):
+        if file_name.startswith('/'):
+            return file_name[1:]
+        return file_name
+
     def file_handler(self):
         """
         Handles uploading files to the relevant object storage
