@@ -1,41 +1,33 @@
+import abc
+import json
 import os
 import re
-import abc
-import time
-import json
 import shutil
+import time
 from datetime import datetime
 from itertools import chain
 
+from cnvrgv2.cli.utils.progress_bar_utils import init_progress_bar_for_cli
+from cnvrgv2.config import Config
+from cnvrgv2.config import CONFIG_FOLDER_NAME
+from cnvrgv2.config import error_messages
+from cnvrgv2.config.routes import COMMIT_REMOVE_FILES
+from cnvrgv2.data import ArtifactsDownloader
+from cnvrgv2.data import FileCompare, LocalFileDeleter
+from cnvrgv2.data import FileDownloader
+from cnvrgv2.data import FileUploader
+from cnvrgv2.data import RemoteFileDeleter
+from cnvrgv2.errors import CnvrgArgumentsError, CnvrgError, CnvrgFileError
+from cnvrgv2.modules.base.dynamic_attributes import DynamicAttributes
+from cnvrgv2.modules.file import File
 from cnvrgv2.modules.folder import Folder
 from cnvrgv2.proxy import HTTP
-from cnvrgv2.errors import CnvrgFileError, CnvrgArgumentsError, CnvrgError
-from cnvrgv2.cli.utils.progress_bar_utils import init_progress_bar_for_cli
-
-from cnvrgv2.config.routes import COMMIT_REMOVE_FILES
-from cnvrgv2.config import CONFIG_FOLDER_NAME
-from cnvrgv2.config import Config
-from cnvrgv2.config import error_messages
-
-from cnvrgv2.data import FileCompare
-from cnvrgv2.data import FileUploader
-from cnvrgv2.data import FileDownloader
-from cnvrgv2.data import RemoteFileDeleter
-from cnvrgv2.data import ArtifactsDownloader
-
-from cnvrgv2.utils.converters import convert_bytes
-from cnvrgv2.utils.url_utils import urljoin
-from cnvrgv2.utils.filter_utils import list_to_multiple_conditions, Operators
-from cnvrgv2.utils.storage_utils import (
-    get_files_and_dirs_recursive,
-    create_dir_if_not_exists,
-    filter_by_mimetypes,
-    create_cnvrgignore,
-    cnvrgignore_exists)
 from cnvrgv2.utils.api_list_generator import api_list_generator
-
-from cnvrgv2.modules.file import File
-from cnvrgv2.modules.base.dynamic_attributes import DynamicAttributes
+from cnvrgv2.utils.converters import convert_bytes
+from cnvrgv2.utils.filter_utils import list_to_multiple_conditions, Operators
+from cnvrgv2.utils.storage_utils import (cnvrgignore_exists, create_cnvrgignore, create_dir_if_not_exists,
+                                         filter_by_mimetypes, get_files_and_dirs_recursive)
+from cnvrgv2.utils.url_utils import urljoin
 from cnvrgv2.utils.validators import validate_directory_name
 
 
@@ -143,19 +135,28 @@ class DataOwner(DynamicAttributes):
 
         return response.attributes["sha1"]
 
-    def _end_commit(self, commit_sha1, tag_images=False):
+    def _end_commit(self, commit_sha1, tag_images=False, with_commit_compare=False):
         """
         End the commit after uploading/deleting files from the dataset.
         @commit_sha1: the commit sha1 to end
         @param tag_images: Will cause images in this commit to be tagged so they can be
             displayed in specific places on front
-        @return: None
+        @param with_commit_compare: the server will delete the commit if it is identical to the previous
+            one (in the case nothing has actually been updated to the server): send last_commit to the server to compare
+             with the current commit. (we don't want to create empty commits)
+        @return: Dict containing commit data
         """
-        self._proxy.call_api(
+        data = {'tag_images': tag_images, 'workflow_slug': self.slug}
+        if with_commit_compare:
+            data["base_commit_sha1"] = self.last_commit
+        response = self._proxy.call_api(
             route=urljoin(self._route, "commits", commit_sha1, "end_commit"),
             http_method=HTTP.PUT,
-            payload={'tag_images': tag_images, 'workflow_slug': self.slug}
+            payload=data
         )
+        # Response will be empty if the commit has been deleted
+        # (in the case nothing has actually been updated to the server).
+        return response.attributes["sha1"] if (response and response.attributes) else None
 
     def reload(self):
         """
@@ -199,53 +200,20 @@ class DataOwner(DynamicAttributes):
         @param git_diff: upload files from git diff output in addition to the given paths
         @return: string - The Commit sha1 that was created
         """
-        fullpaths = []
-        last_commit = None
-        filters = []
 
+        filters = []
         if tag_images:
             filters = ['image']
 
         paths_to_upload = paths
 
         if git_diff:
-            git_diff_files = list(filter(None, self.get_git_diff()))  # Clean from falsy values
-            paths_to_upload = paths_to_upload + git_diff_files
+            paths_to_upload += self._handle_git_files()
 
-        for path in paths_to_upload:
-            is_dir = os.path.isdir(path)
-            is_file = os.path.isfile(path)
+        full_paths = self._get_full_paths(paths_to_upload, filters, pattern)
+        unique_full_paths = list(set(full_paths) - {"./", ".", "/", "//"})
 
-            if is_dir:
-                fullpaths += get_files_and_dirs_recursive(
-                    root_dir=path,
-                    regex=pattern,
-                    not_tmp=True,
-                    project_root=self._config.root,
-                    filters=filters)
-            elif is_file:
-                if filter_by_mimetypes(filters, path):
-                    fullpaths.append(path)
-                else:
-                    print("{} does not match any filter skipping it".format(path))
-            else:
-                # path sent might be a regex
-                files_by_regex = get_files_and_dirs_recursive(
-                    root_dir=".",
-                    regex=path,
-                    not_tmp=True,
-                    filters=filters
-                )
-                if files_by_regex:
-                    fullpaths += files_by_regex
-                else:
-                    # TODO: different handling?
-                    print("{} does not exists skipping it".format(path))
-
-        unique_fullpaths = list(set(fullpaths) - {"./", ".", "/", "//"})
-
-        if not unique_fullpaths and not upload:
-            # TODO: different handling?
+        if not unique_full_paths and not upload:
             return
 
         last_commit = self.local_commit
@@ -253,16 +221,52 @@ class DataOwner(DynamicAttributes):
         if job_slug is not None and last_commit is None and self.start_commit is not None:
             last_commit = self.start_commit["sha1"]
 
-        new_unique_fullpaths = []
+        unique_full_paths = self._filter_deleted_files(unique_full_paths)
+        validate_directory_name(unique_full_paths)
+
+        if not unique_full_paths:
+            return
+
+        return self._upload_files(message, blank, last_commit, job_slug, force, unique_full_paths, override,
+                                  progress_bar_enabled, tag_images, upload)
+
+    def _filter_deleted_files(self, unique_full_paths):
+        result = []
         tmp_folder = "{}/{}".format(self.working_dir, DataOwner.TMP_FOLDER_NAME)
-        for up in unique_fullpaths:
+
+        # This function should run only if tmp folder exist (sync/download)
+        if not os.path.exists(tmp_folder):
+            return unique_full_paths
+
+        for up in unique_full_paths:
             deleted_file = "{}/{}.deleted".format(tmp_folder, up)
+            if not os.path.exists(deleted_file):
+                result.append(up)
 
-            if not os.path.isfile(deleted_file):
-                new_unique_fullpaths.append(up)
+        # Make sure to filter out all paths that are under deleted folders
+        deleted_folders = get_files_and_dirs_recursive(root_dir=tmp_folder, regex=".*deleted/", force=True)
+        for deleted_folder in deleted_folders:
+            # Prepare a regex that matches all paths in the regular dir, that are under a dir marked to be deleted
+            # in the tmp folder
+            matching_path = deleted_folder.replace(".tmp/", "").replace(".deleted", "")
+            regex = re.compile("^(?!{})".format(matching_path))
+            result = [path for path in result if regex.match(path)]
 
-        validate_directory_name(new_unique_fullpaths)
+        return result
 
+    def _handle_git_files(self):
+        return list(filter(None, self.get_git_diff()))  # Clean from falsy values
+
+    def get_git_diff(self):
+        """
+        collects file names from git diff output
+        @return: list of file names from git diff command
+        """
+        command = "git diff --name-only"
+        return os.popen(command).read().strip().split("\n")
+
+    def _upload_files(self, message, blank, last_commit, job_slug, force, paths, override, progress_bar_enabled,
+                      tag_images, upload):
         commit_sha1 = self._start_commit(
             message=message,
             blank=blank,
@@ -271,13 +275,7 @@ class DataOwner(DynamicAttributes):
             force=force
         )
 
-        uploader = FileUploader(
-            self,
-            new_unique_fullpaths,
-            commit=commit_sha1,
-            override=override,
-            progress_bar_enabled=progress_bar_enabled
-        )
+        uploader = self._get_file_uploader(paths, commit_sha1, override, progress_bar_enabled)
 
         while uploader.in_progress:
             time.sleep(0.1)
@@ -288,12 +286,63 @@ class DataOwner(DynamicAttributes):
 
         if upload:
             self.reload()
-            deleter = RemoteFileDeleter(self, commit=commit_sha1)
+            deleter = self._get_remote_file_deleter(commit_sha1)
             while deleter.in_progress:
                 time.sleep(0.1)
-        self._end_commit(commit_sha1=commit_sha1, tag_images=tag_images)
 
-        return commit_sha1
+        # Pass with_commit_compare to end_commit: the server will delete the commit if it is identical to the previous
+        # One (in the case where nothing has actually been updated to the server)
+        with_commit_compare = not override
+        commit = self._end_commit(commit_sha1=commit_sha1, tag_images=tag_images,
+                                  with_commit_compare=with_commit_compare)
+        # Commit will be null if the commit has been deleted
+        # In the case nothing has actually been updated to the server, return last_commit
+        return commit if commit else self.last_commit
+
+    def _get_file_uploader(self, paths, commit_sha1, override, progress_bar_enabled):
+        # this is required for mocking. please don't delete the wrapping function
+        return FileUploader(
+            self,
+            paths,
+            commit=commit_sha1,
+            override=override,
+            progress_bar_enabled=progress_bar_enabled
+        )
+
+    def _get_remote_file_deleter(self, commit_sha1):
+        # this is required for mocking. please don't delete the wrapping function
+        return RemoteFileDeleter(self, commit=commit_sha1)
+
+    def _get_full_paths(self, paths_to_upload, filters, pattern):
+        result = []
+        for path in paths_to_upload:
+            is_dir = os.path.isdir(path)
+            is_file = os.path.isfile(path)
+
+            if is_dir:
+                result += get_files_and_dirs_recursive(
+                    root_dir=path,
+                    regex=pattern,
+                    project_root=self._config.root,
+                    filters=filters)
+                continue
+
+            if is_file and filter_by_mimetypes(filters, path):
+                result.append(path)
+                continue
+
+            # path sent might be a regex
+            files_by_regex = get_files_and_dirs_recursive(
+                root_dir=".",
+                regex=path,
+                filters=filters)
+
+            if files_by_regex:
+                result += files_by_regex
+                continue
+
+            print("{} does not exists skipping it".format(path))
+        return result
 
     def remove_files(self, paths, message="", progress_bar_enabled=False):
         """
@@ -301,7 +350,7 @@ class DataOwner(DynamicAttributes):
         @param paths: List of file paths to remove (regex and wildcards allowed)
         @param message: Commit message
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
-        @return: None
+        @return: Number of files removed
         """
         progress_bar = None
         commit_sha1 = self._start_commit(message=message)
@@ -334,6 +383,7 @@ class DataOwner(DynamicAttributes):
             removed_files_count += meta["removed_files_count"]
 
         self._end_commit(commit_sha1=commit_sha1)
+        return removed_files_count
 
     def _remove_api_call(self, commit_sha1, data):
         """
@@ -348,21 +398,27 @@ class DataOwner(DynamicAttributes):
             payload=data
         ).meta
 
-    def clone(self, progress_bar_enabled=False, override=False, commit=None):
+    def clone(self, progress_bar_enabled=False, override=False, commit=None, use_cached=False):
         """
         Clones the remote project / dataset
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
-        @param override: Boolean stating whether or not we should re-clone even if the project / dataset already cloned
+        @param override: Boolean stating whether we should re-clone even if the project / dataset already cloned
         @param commit: [String] sha1 of the commit to clone
+        @param use_cached: Boolean stating whether to use nfs cache link or not
         @return: None
         """
         self.reload()
 
         if not os.path.exists(self.slug):
             os.makedirs(self.slug)
-        elif os.path.exists(self.slug + '/' + CONFIG_FOLDER_NAME) and not override:
-            # If already cloned and override set to false - won't clone again
-            return
+        elif os.path.exists(self.slug + '/' + CONFIG_FOLDER_NAME):
+            if not override:
+                # If already cloned and override set to false - won't clone again
+                return
+            else:
+                # If already cloned and override set to true - remove config file so that verify will fail until the
+                # data owner is cloned again
+                shutil.rmtree(self.slug + '/' + CONFIG_FOLDER_NAME)
 
         if commit and commit.lower() != 'latest':
             self.last_commit = commit
@@ -370,7 +426,7 @@ class DataOwner(DynamicAttributes):
         old_working_dir = self.working_dir
         self.working_dir = "{}/{}".format(old_working_dir, self.slug)
 
-        downloader = FileDownloader(self, progress_bar_enabled=progress_bar_enabled)
+        downloader = FileDownloader(self, progress_bar_enabled=progress_bar_enabled, use_cached=use_cached)
 
         while downloader.in_progress:
             time.sleep(1)
@@ -458,20 +514,20 @@ class DataOwner(DynamicAttributes):
         while downloader.in_progress:
             time.sleep(1)
 
-        self.working_dir = old_working_dir
+        if downloader.errors:
+            raise CnvrgError(downloader.errors.args)
 
-        # TODO fix and uncomment
-        """
-        # remove all folders needed that should be deleted
-        folder_deleter = LocalFileDeleter(self, mode="folders")
-        while folder_deleter.in_progress:
-            time.sleep(1)
+        self.working_dir = old_working_dir
 
         # put all files that need to be deleted at .tmp with .deleted extension
         file_deleter = LocalFileDeleter(self)
         while file_deleter.in_progress:
             time.sleep(1)
-        """
+
+        # remove all folders needed that should be deleted
+        folder_deleter = LocalFileDeleter(self, mode="folders")
+        while folder_deleter.in_progress:
+            time.sleep(1)
 
         if not sync:
             self.move_files_from_tmp()
@@ -480,16 +536,17 @@ class DataOwner(DynamicAttributes):
 
         os.chdir(context_working_dir)
 
-    def sync(self, job_slug=None, git_diff=False):
+    def sync(self, job_slug=None, git_diff=False, progress_bar_enabled=False):
         """
         Sync local project / dataset to remote
         @param job_slug: Slug of a job to upload the files to
         @param git_diff: upload only files from git diff output
+        @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
         @return: None
         """
         try:
-            self.download(sync=True)
-            self.upload(sync=True, job_slug=job_slug, git_diff=git_diff)
+            self.download(sync=True, progress_bar_enabled=progress_bar_enabled)
+            self.upload(sync=True, progress_bar_enabled=progress_bar_enabled, job_slug=job_slug, git_diff=git_diff)
         finally:
             # make sure the tmp folder used by download and upload will be deleted
             if os.path.exists(DataOwner.TMP_FOLDER_NAME):
@@ -540,7 +597,7 @@ class DataOwner(DynamicAttributes):
         """
         tmp_folder = "{}/{}".format(self.working_dir, DataOwner.TMP_FOLDER_NAME)
         try:
-            fullpaths = get_files_and_dirs_recursive(root_dir='.', not_tmp=True)
+            fullpaths = get_files_and_dirs_recursive(root_dir='.')
             unique_fullpaths = list(set(fullpaths) - {"./", ".", "/", "//"})
 
             if unique_fullpaths:
@@ -548,32 +605,35 @@ class DataOwner(DynamicAttributes):
                 while compare.in_progress:
                     time.sleep(1)
 
-            downloaded_files = get_files_and_dirs_recursive(root_dir=tmp_folder, only_files=True)
+            downloaded_files = get_files_and_dirs_recursive(root_dir=tmp_folder, force=True)
             for df in downloaded_files:
                 if df == ".tmp/" or df == ".tmp/.cnvrgignore":
                     continue
 
-                if df.endswith('.deleted'):
+                if df.endswith('.deleted') or df.endswith('.deleted/'):
                     original_file = re.sub(DataOwner.TMP_FOLDER_NAME, self.working_dir, df)
                     original_file = re.sub(".deleted", "", original_file)
                     if(os.path.isfile(original_file)):
                         os.remove(original_file)
+                    elif(os.path.isdir(original_file)):
+                        shutil.rmtree(original_file)
                     continue
 
                 new_path = re.sub(DataOwner.TMP_FOLDER_NAME, self.working_dir, df)
                 create_dir_if_not_exists(new_path)
+
+                # Prevents moving folders with content. Generally, creation of folders is done when dealing with files
+                # inside the folders, except for empty folders. This makes sure that only empty folders will be copied
+                if os.path.isdir(df) and (len(os.listdir(df)) != 0 or len(os.listdir(new_path)) != 0):
+                    continue
+
                 os.rename(df, new_path)
         finally:
             if os.path.exists(tmp_folder):
                 shutil.rmtree(tmp_folder)
 
-    def get_git_diff(self):
-        """
-        collects file names from git diff output
-        @return: list of file names from git diff command
-        """
-        command = "git diff --name-only"
-        return os.popen(command).read().strip().split("\n")
+    def _get_git_diff_files(self):
+        return list(filter(None, self.get_git_diff()))   # Clean from falsy values
 
     def _list(self, mode, commit_sha1=None, query=None, query_raw=None, sort="-id"):
 
