@@ -1,6 +1,5 @@
 import time
 from datetime import datetime
-
 from cnvrgv2.data import ArtifactsDownloader
 from cnvrgv2.config import routes
 from cnvrgv2.config.error_messages import EMPTY_ARGUMENT, ARGUMENT_BAD_TYPE, NOT_LIST
@@ -361,3 +360,25 @@ class Experiment(WorkflowInstanceBase):
             time.sleep(poll_interval)
             self.reload()
         return self.status
+
+    def merge_to_master(self, commit_sha1=None):
+        """
+        Merge commit to master (used to merge experiment artifacts to master)
+        @param commit_sha1: default is latest
+        @return: The new commit sha1
+        """
+
+        # Importing here to avoid circular dependencies (experiment <-> project)
+        from cnvrgv2 import Project
+        project = Project(context=self._context, slug=self.scope["project"])
+        if project.git:
+            return None
+        if not commit_sha1:
+            commit_sha1 = self.last_commit
+        merge_to_master_route = routes.PROJECT_COMMIT_BASE.format(self.scope["organization"], self.scope["project"])
+        response = self._proxy.call_api(
+            route=urljoin(merge_to_master_route, commit_sha1, "merge_to_master"),
+            http_method=HTTP.POST,
+            payload={'sha1': commit_sha1}
+        )
+        return response.attributes['sha1']
