@@ -1,15 +1,16 @@
-import os
-import errno
-import hashlib
 import fnmatch
-import requests
+import hashlib
 import mimetypes
-import shutil
+import os
 import pathlib
-from os import path, walk
-from Crypto.Cipher import AES
+import shutil
 from base64 import b64decode
+from os import path, walk
+from pathlib import Path
+
 import pkg_resources
+import requests
+from Crypto.Cipher import AES
 
 
 def unpad(s):
@@ -63,13 +64,7 @@ def create_dir_if_not_exists(local_path):
     @return: None
     """
     dir_path = os.path.dirname(local_path)
-    if dir_path and not os.path.exists(dir_path):
-        try:
-            os.makedirs(dir_path)
-        except OSError as e:
-            if errno.EEXIST != e.errno:
-                # TODO: handle exception
-                raise
+    Path(dir_path).mkdir(parents=True, exist_ok=True)
 
 
 def get_relative_path(full_path):
@@ -109,7 +104,7 @@ def get_cnvrgignore_rules(path):
     @return: [List] of rules
     """
     cnvrgignore_path = os.path.join(path, '.cnvrgignore')
-    rules = ['.cnvrg/']
+    rules = ['.cnvrg/', '.tmp/']
     if not os.path.exists(cnvrgignore_path):
         return rules
     with open(cnvrgignore_path, 'r') as f:
@@ -151,16 +146,16 @@ def cnvrgignore_exists(path):
 def get_files_and_dirs_recursive(
         root_dir=".",
         regex="*",
-        only_files=False,
-        not_tmp=False,
         project_root="",
-        filters=None):
+        filters=None,
+        force=False
+):
     """
     Recursively traverse a given directory and get all of the relevant files and folders within
     @param root_dir: String representing the directory path
     @param regex: String representing the regex to filter out files/folders
-    @param only_files: Boolean representing whether or not we want to receive only files
     @param project_root: String representing the project root path
+    @param force: Get all files and dirs regardless of .cnvrgignore rules. E.g, used to get .tmp folder
     @return: List
     """
     project_root = append_trailing_slash(project_root) if project_root else ''
@@ -169,24 +164,24 @@ def get_files_and_dirs_recursive(
     for root, dirs, files in walk(root_dir, topdown=False):
         for name in files:
             file_path = get_relative_path(path.join(root, name)).replace(project_root, "")
-            if match_ignore(file_path, project_root):
+            if not force and match_ignore(file_path, project_root):
                 continue
             full_paths.append(file_path)
         for name in dirs:
-            if not only_files:
-                dir_path = append_trailing_slash(get_relative_path(path.join(root, name))
-                                                 .replace(project_root, ""))
-                if match_ignore(dir_path, project_root):
-                    continue
-                full_paths.append(dir_path)
+            dir_path = append_trailing_slash(get_relative_path(path.join(root, name))
+                                             .replace(project_root, ""))
+            if not force and match_ignore(dir_path, project_root):
+                continue
+            full_paths.append(dir_path)
+
+    # Add the folder itself, if it's an empty one
+    if len(os.listdir(root_dir)) == 0:
+        dir_path = append_trailing_slash(get_relative_path(root_dir).replace(project_root, ""))
+        full_paths.append(dir_path)
 
     if regex:
         full_paths = fnmatch.filter(full_paths, regex)
 
-    # todo add .tmp to rules
-    if not_tmp:
-        full_paths = [item for item in full_paths if not item.startswith(".tmp")]
-
     if filters:
         full_paths = [item for item in full_paths if filter_by_mimetypes(filters, item)]
 
